#
# spec file for package extreme-tuxracer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oname   etr
Name:           extreme-tuxracer
Version:        0.8.3
Release:        1.2
Summary:        Racing game featuring Tux the Linux Penguin
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Race
URL:            https://sourceforge.net/projects/extremetuxracer/
Source:         https://downloads.sourceforge.net/extremetuxracer/%{oname}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  sfml2-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
Requires:       %{name}-data = %{version}

%description
Extreme Tux Racer is a racing game featuring Tux
the Linux Penguin. Extreme Tux Racer continues in the tracks
of Tux Racer and its forks.

%package data
Summary:        Data files for %{name}
Group:          Amusements/Games/3D/Race
BuildArch:      noarch

%description data
This package contains the data files for %{name}.

%prep
%setup -q -n %{oname}-%{version}

%build
%configure
%make_build

%install
%make_install
%fdupes -s %{buildroot}%{_prefix}

# Already included by the doc macro
rm -fr %{buildroot}%{_datadir}/doc

%files
%doc AUTHORS NEWS doc/code doc/courses_events doc/guide doc/score_algorithm
%license COPYING
%{_bindir}/%{oname}
%{_datadir}/pixmaps/%{oname}.png
%{_datadir}/pixmaps/%{oname}.svg
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/*.metainfo.xml

%files data
%{_datadir}/%{oname}/

%changelog
* Wed Oct 18 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.8.3:
  * Respect XDG_CONFIG_HOME at systems other than Windows
  * Metainfo and desktop files have now reverse domain-name
  * Other metainfo format updates
  * Course files converted to UTF-8
  * Autotools build now have year 2038 support, if at least
    version 2.73 of autoconf is used in bootstrapping.
  * Updated French translation
* Sat Jul  9 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 0.8.2:
  * Fixed a crash when entering an event with the course group changed earlier.
    Now the course group is always resetted to the default one before entering
    an event.
  * Appdata/Metainfo file is now installed to <prefix>/share/metainfo, like
    current specification requires.
  * Also the project license, not only license of the metadata, is defined
    in the appdata file.
  * etr.png icon regenerated from the etr.svg in 64x64 size for better quality.
  * New translations:
    + Italian
  * Updated translations:
    + Swedish
    + Finnish
    + Romanian
* Tue Jul 27 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * Autotools build now prefers linking against libOpenGL over libGL
  * New translations
  * Esperanto
  * Dutch
  * Romanian
  * Updated translations
  * French
  * Swedish
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update 0.8.0
  * small improvements & bug fixes
  * Extreme Tux Racer now compiles with clang++
  * Minimum SFML version is now 2.4
  * Autotools based build method can use opengl32 & glu32
    instead of libGL & libGLU
* Sat Jul 14 2018 jengelh@inai.de
- Trim filler wording from descriptions.
* Fri Jun 22 2018 antoine.belvire@opensuse.org
- Update to version 0.7.5:
  * Fixed a crash when score is not good enough to enter high score
    list.
  * Extreme Tux Racer comes with AppStream metadata.
- Remove appdata.xml from sources since it is now included in
  upstream tarball.
- Clean spec file.
- Create data subpackage.
* Sat Feb 18 2017 mailaender@opensuse.org
- Update to version 0.7.4
- Add appdata.xml for https://en.opensuse.org/openSUSE:AppStore
* Sun Jul 24 2016 nemysis@openSUSE.org
- Update to 0.7.3, please see
  /usr/share/doc/packages/extreme-tuxracer/NEWS
* Fri Apr 15 2016 nemysis@openSUSE.org
- Update to 0.7.2, please see
  /usr/share/doc/packages/extreme-tuxracer/NEWS
* Thu Feb  4 2016 nemysis@openSUSE.org
- Update to 0.7.1, please see
  /usr/share/doc/packages/extreme-tuxracer/NEWS
* Wed Feb  3 2016 nemysis@openSUSE.org
- Update to 0.7.0, please see
  /usr/share/doc/packages/extreme-tuxracer/NEWS
- license update: GPL-2.0+ No indication that this is GPL-2.0 (only)
- Remove BuildRequires, changed by Upstream for dos2unix,
  pkgconfig(SDL_image), pkgconfig(SDL_mixer and pkgconfig(sdl)
- Add BuildRequires, changed by Upstream for sfml2-devel
- Add NEWS to Documentation
* Wed Sep 23 2015 nemysis@openSUSE.org
- Use %%{oname} instead of etr
- Change URL
- Use BuildRequires pkgconfig() instead of devel packages
- Add BuildRequires for dos2unix
- Change Description
- Use default autoreconf -fi and %%make_install
- Use for suse_update_desktop_file and fdupes %%if 0%%{?suse_version}
* Mon Jan 12 2015 p.drouand@gmail.com
- Update to version 0.6.0
  + No changelog available; new maitainers
- Add SDL_image-devel requirement; new upstream dependency
- Remove some hacks; upstream provide his own desktop file
- Include AUTHORS, COPYING and development related documentation
  in the package
- Remove tcl-devel requirement; the Tcl scripting library has been
  completely replaced with the SP library
- Remove obsolete patches
  + avp.patch
  + libpng14.patch
* Sat Dec  6 2014 schwab@linux-m68k.org
- Fix GenericName in desktop file
* Mon Jan 28 2013 joop.boonen@opensuse.org
- Added missing BuildRequirement libXi-devel libXmu-devel libXt-devel
- Cleaned the spec file up
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit glu dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Thu Apr  8 2010 pgajdos@suse.cz
- build with new libpng14
* Tue Mar  9 2010 adam@mizerski.pl
- added creation of desktop file (/usr/share/applications/etracer.desktop)
- in BuildRequires removed unnneded linux-kernel-headers
- fixed symlink /usr/bin/extreme-tuxracer -> etracer
- added missing %%clean section
- removed changelog from spec, since it should be only in this (extreme-tuxracer.changes) file
- fixed misspellings in description
* Tue Jun  2 2009 mmaher@suse.de
- fixed bug 443377
* Wed Sep 24 2008 jw@suse.de
- added /usr/bin/extreme-tuxracer as a convenience symlink.
* Mon Jan 28 2008 mmaher@suse.de
- Updated to 0.4
  * new Graphics
  * new Sounds
  * new Maps
  * new Specials
  * Some bugs fixed
* Tue Oct  2 2007 mmaher@suse.de
- initial Build
